summaryrefslogtreecommitdiff
path: root/bip-0075/paymentrequest.proto
diff options
context:
space:
mode:
Diffstat (limited to 'bip-0075/paymentrequest.proto')
-rw-r--r--bip-0075/paymentrequest.proto18
1 files changed, 12 insertions, 6 deletions
diff --git a/bip-0075/paymentrequest.proto b/bip-0075/paymentrequest.proto
index 1c9cc8e..912fcd3 100644
--- a/bip-0075/paymentrequest.proto
+++ b/bip-0075/paymentrequest.proto
@@ -33,19 +33,25 @@ message PaymentRequest {
optional bytes pki_data = 3; // depends on pki_type
required bytes serialized_payment_details = 4; // PaymentDetails
optional bytes signature = 5; // pki-dependent signature
+ optional uint32 status_code = 1000; // Payment Protocol status code
+ optional string status_message = 1001; // Human-readable Payment Protocol status message
}
message X509Certificates {
repeated bytes certificate = 1; // DER-encoded X.509 certificate chain
}
message Payment {
- optional bytes merchant_data = 1; // From PaymentDetails.merchant_data
- repeated bytes transactions = 2; // Signed transactions that satisfy PaymentDetails.outputs
- repeated Output refund_to = 3; // Where to send refunds, if a refund is necessary
- optional string memo = 4; // Human-readable message for the merchant
+ optional bytes merchant_data = 1; // From PaymentDetails.merchant_data
+ repeated bytes transactions = 2; // Signed transactions that satisfy PaymentDetails.outputs
+ repeated Output refund_to = 3; // Where to send refunds, if a refund is necessary
+ optional string memo = 4; // Human-readable message for the merchant
+ optional uint32 status_code = 1000; // Payment Protocol status code
+ optional string status_message = 1001; // Human-readable Payment Protocol status message
}
message PaymentACK {
- required Payment payment = 1; // Payment message that triggered this ACK
- optional string memo = 2; // Human-readable message for customer
+ required Payment payment = 1; // Payment message that triggered this ACK
+ optional string memo = 2; // Human-readable message for customer
+ optional uint32 status_code = 1000; // Payment Protocol status code
+ optional string status_message = 1001; // Human-readable Payment Protocol status message
}
// BIP-IR Extensions